@@ -8,14 +8,15 @@ import six
 import xml.etree.ElementTree as ET
 
 from .invariant import (CAPTURE_STATUS_CAPTURING, DECODE_PLAIN_TEXT, DECODE_HTML,
-    DECODE_TAG_STREAM, ENGINE_FORMAT_HTML, ENGINE_FORMAT_PLAIN,
-    ENGINE_FORMAT_TAG_STREAM, ENGINE_OP_GET, ENGINE_OP_POST, ENGINE_OP_DELETE)
+    DECODE_TAG_STREAM)
 
 from .adapter import Adapter
 # from .callstatistic import CallStatistic
+from .capturetemplate import CaptureTemplate
 # from .expertquery import ExpertQuery
 # from .expertresult import ExpertResult
-from .mediainfo import MediaInfo
+from .invariant import EngineDataFormat as DF, EngineOperation as EO
+from .mediainformation import MediaInformation
 # from .nodestatistic import NodeStatistic
 from .omnierror import OmniError
 from .omniid import OmniId
@@ -43,6 +44,12 @@ status_map = {
     8449 : 'Start Stop Active'
 }
 
+jtrue = 'true'
+jfalse = 'false'
+
+def jbool(b):
+    """Returns 'true' if 'b' is True else 'false'."""
+    return jtrue if b else jfalse
 
 def _summary_xml_to_stats_list(xml):
     type_dict = [
@@ -130,7 +137,7 @@ _capture_prop_dict = {
     'indexingEnabled' : 'option_indexing',
     'linkSpeed' : 'link_speed',
     'loggedOnUserSid' : 'logged_on_user_sid',
-    'mediaInfo' : 'media_info',
+    'mediaInfo' : 'media_information',
     'mediaSubType' : 'media_sub_type',
     'mediaType' : 'media_type',
     'modificationBy' : 'modified_by',
@@ -326,8 +333,8 @@ class Capture(object):
     logged_on_user_sid = ''
     """The currenlty logged on user."""
 
-    media_info = None
-    """The :class:`MediaInfo <omniscript.mediainfo.MediaInfo>` object
+    media_information = None
+    """The :class:`MediaInformation <omniscript.mediainformation.MediaInformation>` object
     of the capture.
     """
 
@@ -494,7 +501,7 @@ class Capture(object):
         self.id = Capture.id
         self.link_speed = Capture.link_speed
         self.logged_on_user_sid = Capture.logged_on_user_sid
-        self.media_info = Capture.media_info
+        self.media_information = Capture.media_information
         self.media_sub_type = Capture.media_sub_type
         self.media_type = Capture.media_type
         self.modification_time = Capture.modification_time
@@ -534,7 +541,10 @@ class Capture(object):
         self.option_web = Capture.option_web
         self._load(props)
 
-    def __str__(self):
+    def __repr__(self) -> str:
+        return f'Capture: {self.name}'
+
+    def __str__(self) -> str:
         return f'Capture: {self.name}'
 
     # def _get_properties(self):
@@ -582,8 +592,8 @@ class Capture(object):
                                 'data_stop_time', 'modification_time',
                                 'start_time', 'stop_time'):
                         setattr(self, a, PeekTime(v))
-                    elif a == 'media_info':
-                        setattr(self, a, MediaInfo(v))
+                    elif a == 'media_information':
+                        setattr(self, a, MediaInformation(v))
         # first_packet is a packet index (index into the capture buffer),
         #   convert it into a packet number(?).
         if self.first_packet > 0:
@@ -634,16 +644,16 @@ class Capture(object):
     #         return None
     #     return self._context.get_call_statistics()
     
-    def get_capture_template(self):
-        """Get the
-        :class:`CaptureTemplate <omniscript.capturetemplate.CaptureTemplate>`
-        of this capture.
+    # def get_capture_template(self):
+    #     """Get the
+    #     :class:`CaptureTemplate <omniscript.capturetemplate.CaptureTemplate>`
+    #     of this capture.
 
-        Returns:
-            A :class:`CaptureTemplate <omniscript.capturetemplate.CaptureTemplate>`
-            object.
-        """
-        return self._engine.get_capture_template(self)
+    #     Returns:
+    #         A :class:`CaptureTemplate <omniscript.capturetemplate.CaptureTemplate>`
+    #         object.
+    #     """
+    #     return self._engine.get_capture_template(self)
 
     # def get_country_stats(self, refresh=False):
     #     """Returns a list of
@@ -679,6 +689,13 @@ class Capture(object):
     #         return None
     #     return self._context.get_node_statistics()
 
+    def get_options(self):
+        """Returns the Capture's Options in a Capture Template object."""
+        pr = self.perf('get_options')
+        cmd = f'captures/{self.id.format()}/options/'
+        props = self._engine._issue_command(cmd, pr)
+        return CaptureTemplate(props=props, engine=self._engine) if props else None
+
     def get_packet_data(self, number):
         """Returns a bytearry of the packet data.
 
@@ -691,8 +708,9 @@ class Capture(object):
         self.refresh()
         if number < self.first_packet:
             return None
-        command = f'captures/{self.id.format()}/packets/{number}/'
-        resp = self._engine._issue_command(command, ENGINE_OP_GET)
+        pr = self.perf('get_packet_data')
+        cmd = f'captures/{self.id.format()}/packets/{number}/'
+        resp = self._engine._issue_command(cmd, pr)
         data = bytearray(resp['data'])
         return data
 
@@ -709,16 +727,17 @@ class Capture(object):
         if number < self.first_packet:
             return None
         if format == DECODE_PLAIN_TEXT:
-            decode = ENGINE_FORMAT_PLAIN
+            decode = DF.PLAIN
         elif format == DECODE_HTML:
-            decode = ENGINE_FORMAT_HTML
+            decode = DF.HTML
         elif format == DECODE_TAG_STREAM:
-            decode = ENGINE_FORMAT_TAG_STREAM
+            decode = DF.TAG_STREAM
         else:
             raise OmniError('Unrecognized format parameter.')
 
+        pr = self.perf('get_packet_decode')
         command = f'captures/{self.id.format()}/packets/{number}/'
-        resp = self._engine._issue_command(command, ENGINE_OP_GET, decode)
+        resp = self._engine._issue_command(command, pr, format=decode)
         return resp
 
     def get_packets(self, first, count=1):
@@ -737,15 +756,16 @@ class Capture(object):
         req_props = [
             ('firstPacketNumber', first),
             ('packetCount', count),
-            ('showLogical', True),
-            ('showAddressNames', False),
-            ('showPortNames', False)
+            ('showLogical', jtrue),
+            ('showAddressNames', jfalse),
+            ('showPortNames', jfalse)
         ]
         column_dict = Packet.get_prop_dict()
         for k in column_dict.keys():
             req_props.append( ('columns', k) )
+        pr = self.perf('get_packets')
         command = f'captures/{self.id.format()}/packet-list/'
-        props = self._engine._issue_command(command, ENGINE_OP_GET, params=req_props)
+        props = self._engine._issue_command(command, pr, params=req_props)
         return _create_packet_list(props)
 
     # def get_packets_old(self, indices):
@@ -892,6 +912,11 @@ class Capture(object):
     #     """
     #     return self._engine.modify_capture(template, self)
 
+    def perf(self, message):
+        if self._engine:
+            return self._engine.perf(message)
+        return None
+
     # def query_expert(self, query_list):
     #     """Query the Expert with one or more
     #     :class:`ExpertQuery <omniscript.expertquery.ExpertQuery>` objects.
@@ -916,7 +941,8 @@ class Capture(object):
         """Refresh the properties of this object.
         The statitics cache is cleared.
         """
-        props = self._engine._issue_command(f'captures/{self.id.format()}/')
+        pr = self.perf('capture refresh')
+        props = self._engine._issue_command(f'captures/{self.id.format()}/', pr)
         if props is not None:
             self.__init__(self._engine, props)
             return True
@@ -987,8 +1013,9 @@ class Capture(object):
         if self.id is None:
             self.logger.error(f'Failed to get the id for Capture: {self.name}')
             return False
+        pr = self.perf('capture start')
         command = f'running-captures/{self.id.format()}/'
-        props = self._engine._issue_command(command, ENGINE_OP_POST)
+        props = self._engine._issue_command(command, pr, EO.POST)
         return (props is not None)
 
     def stop(self):
@@ -998,8 +1025,9 @@ class Capture(object):
         if self.id is None:
             self.logger.error(f'Failed to get the id for Capture: {self.name}')
             return False
+        pr = self.perf('capture stop')
         command = f'running-captures/{self.id.format()}/'
-        props = self._engine._issue_command(command, ENGINE_OP_DELETE)
+        props = self._engine._issue_command(command, pr, EO.DELETE)
         return (props is not None)
 
 
