@@ -213,6 +213,15 @@ def _hex_string_to_string(value):
     return ''.join(chr(int(value[i:i+2], 16)) for i in range(0, len(value), 2)).strip('\0')
 
 
+def parse_port_list(value):
+    if isinstance(value, six.string_types):
+        port_list = value.split(' ')
+        pl = [OmniPort(p) for p in port_list if p]
+        return pl
+    else:
+        return [OmniPort(value)]
+
+
 def _string_to_hex_string(value, pad=0):
     """Return a string of hex characters from a string.
 
@@ -438,12 +447,12 @@ class AddressNode(FilterNode):
     :class:`FilterNode <omniscript.filternode.FilterNode>` class.
     """
 
-    address_1 = None
-    """The first address as an
+    address_list_1 = None
+    """The first address as a list of
     :class:`OmniAddress <omniscript.omniaddress.OmniAddress>` object."""
 
-    address_2 = None
-    """The second address as an
+    address_list_2 = None
+    """The second address as a list of
     :class:`OmniAddress <omniscript.omniaddress.OmniAddress>` object."""
     
     option_accept_1_to_2 = False
@@ -476,17 +485,17 @@ class AddressNode(FilterNode):
 
     def __init__(self, props=None):
         super(AddressNode, self).__init__()
-        self.address_1 = AddressNode.address_1
-        self.address_2 = AddressNode.address_2
+        self.address_list_1 = AddressNode.address_list_1
+        self.address_list_2 = AddressNode.address_list_2
         self.option_accept_1_to_2 = AddressNode.option_accept_1_to_2
         self.option_accept_2_to_1 = AddressNode.option_accept_2_to_1
         self._load(props)
 
     def __str__(self):
         return (f'{AddressNode._class_name}: '
-                f'{self.address_1} '
+                f'{self.address_list_1} '
                 f'{_direction_string(self.option_accept_1_to_2, self.option_accept_2_to_1)} '
-                f'{self.address_2}')
+                f'{self.address_list_2}')
 
     @property
     def accept_1_to_2(self):
@@ -524,34 +533,34 @@ class AddressNode(FilterNode):
                 self.option_accept_1_to_2 = v
             elif a == AddressNode._tag_accept_2_to_1:
                 self.option_accept_2_to_1 = v
-        self.address_1 = OmniAddress('addr1', _address_1, _address_type).address
-        self.address_2 = OmniAddress('addr2', _address_2, _address_type).address
+        self.address_list_1 = OmniAddress('addr1', _address_1, _address_type).address_list
+        self.address_list_2 = OmniAddress('addr2', _address_2, _address_type).address_list
 
     def _store(self, props):
         if not isinstance(props, dict):
             return
-        _type = (self.address_1.address_type if self.address_1
-                 else self.address_2.type if self.address_2 else 0)
+        addr_1 = [str(a) for a in self.address_list_1] if self.address_list_1 else []
+        addr_2 = [str(a) for a in self.address_list_2] if self.address_list_2 else []
+        _type = (self.address_list_1[0].address_type if self.address_list_1
+            else self.address_list_2[0].address_type if self.address_list_1 else 0)
         props[_json_type] = _type
-        props[AddressNode._json_address_1] = (self.address_1.format(False)
-                                              if self.address_1 else "")
-        props[AddressNode._json_address_2] = (self.address_2.format(False)
-                                              if self.address_2 else "")
+        props[AddressNode._json_address_1] = ' '.join(addr_1) if addr_1 else ''
+        props[AddressNode._json_address_2] = ' '.join(addr_2) if addr_2 else ''
         props[_json_accept_1_to_2] = self.option_accept_1_to_2
         props[_json_accept_2_to_1] = self.option_accept_2_to_1
         super(AddressNode, self)._store(props)
 
     def to_string(self, pad, operation=""):
-        criteria  = '%s%s%s: %s%s %s %s' % (
-            ''.ljust(pad * FilterNode.pad_depth),
-            operation,
-            AddressNode._display_name,
-            _invert_string(self.option_inverted),
-            str(self.address_1),
-            _direction_string(
-                self.option_accept_1_to_2, self.option_accept_2_to_1),
-            str(self.address_2))
-        return criteria + FilterNode.to_string(self, pad)
+        addr_1 = [str(a) for a in self.address_list_1] if self.address_list_1 else []
+        addr_2 = [str(a) for a in self.address_list_2] if self.address_list_2 else []
+        return (
+            f'{"".ljust(pad * FilterNode.pad_depth)}{operation} {AddressNode._display_name}:'
+            f'{_invert_string(self.option_inverted)}'
+            f'{" ".join(addr_1) if addr_1 else "any"} '
+            f'{_direction_string(self.option_accept_1_to_2, self.option_accept_2_to_1)} '
+            f'{" ".join(addr_2) if addr_2 else "any"} '
+            f'{FilterNode.to_string(self, pad)}'
+        )
 
 
 class BpfNode(FilterNode):
@@ -1144,12 +1153,12 @@ class PortNode(FilterNode):
     :class:`FilterNode <omniscript.filternode.FilterNode>` class.
     """
 
-    port_1 = None
-    """The first port as an
+    port_list_1 = None
+    """The first list of
     :class:`OmniPort <omniscript.omniport.OmniPort>` object."""
 
-    port_2 = None
-    """The second port as an
+    port_list_2 = None
+    """The second list of
     :class:`OmniPort <omniscript.omniport.OmniPort>` object."""
     
     option_accept_1_to_2 = False
@@ -1178,8 +1187,8 @@ class PortNode(FilterNode):
 
     def __init__(self, props=None):
         super(PortNode, self).__init__()
-        self.port_1 = PortNode.port_1
-        self.port_2 = PortNode.port_2
+        self.port_list_1 = PortNode.port_list_1
+        self.port_list_2 = PortNode.port_list_2
         self.option_accept_1_to_2 = PortNode.option_accept_1_to_2
         self.option_accept_2_to_1 = PortNode.option_accept_2_to_1
         self._load(props)
@@ -1197,9 +1206,9 @@ class PortNode(FilterNode):
         for k,v in props.items():
             a = PortNode._port_node_prop_dict.get(k)
             if a == PortNode._tag_port_1:
-                self.port_1 = OmniPort(v)
+                self.port_list_1 = parse_port_list(v)
             elif a == PortNode._tag_port_2:
-                self.port_2 = OmniPort(v)
+                self.port_list_2 = parse_port_list(v)
             elif a == PortNode._tag_accept_1_to_2:
                 self.option_accept_1_to_2 = v
             elif a == PortNode._tag_accept_2_to_1:
@@ -1208,26 +1217,28 @@ class PortNode(FilterNode):
     def _store(self, props):
         if not isinstance(props, dict):
             return
-        _type = (self.port_1.port_type if self.port_1
-                 else self.port_2.port_type if self.port_2 else 0)
+        port_1 = [str(a) for a in self.port_list_1] if self.port_list_1 else []
+        port_2 = [str(a) for a in self.port_list_2] if self.port_list_2 else []
+        _type = (self.port_list_1[0].port_type if self.port_list_1
+                 else self.port_list_2[0].port_type if self.port_list_2 else 0)
         props[_json_type] = _type
-        if self.port_1:
-            props[PortNode._json_port_1] = str(self.port_1)
-        if self.port_2:
-            props[PortNode._json_port_2] = str(self.port_2)
+        props[PortNode._json_port_1] = ' '.join(port_1) if port_1 else ''
+        props[PortNode._json_port_2] = ' '.join(port_2) if port_2 else ''
         props[_json_accept_1_to_2] = self.option_accept_1_to_2
         props[_json_accept_2_to_1] = self.option_accept_2_to_1
         super(PortNode, self)._store(props)
 
     def to_string(self, pad, operation=""):
-        criteria = (''.ljust(pad * FilterNode.pad_depth)
-            + operation
-            + PortNode._display_name
-            + _invert_string(self.option_inverted)
-            + str(self.port_1)
-            + _direction_string(self.option_accept_1_to_2, self.option_accept_2_to_1)
-            + str(self.port_2))
-        return criteria + FilterNode.to_string(self, pad)
+        ports_1 = [str(p) for p in self.port_list_1] if self.port_list_1 else []
+        ports_2 = [str(p) for p in self.port_list_2] if self.port_list_2 else []
+        return (
+            f'{"".ljust(pad * FilterNode.pad_depth)}{operation} {PortNode._display_name}:'
+            f'{_invert_string(self.option_inverted)}'
+            f'{" ".join(ports_1) if ports_1 else "any"} '
+            f'{_direction_string(self.option_accept_1_to_2, self.option_accept_2_to_1)} '
+            f'{" ".join(ports_2) if ports_2 else "any"} '
+            f'{FilterNode.to_string(self, pad)}'
+        )
 
 
 class ProtocolNode(FilterNode):
