@@ -11,13 +11,13 @@ import xml.etree.ElementTree as ET
 
 import omniscript
 
-from .invariant import (DECODE_PLAIN_TEXT, DECODE_HTML, DECODE_TAG_STREAM, ENGINE_FORMAT_HTML,
-    ENGINE_FORMAT_PLAIN, ENGINE_FORMAT_TAG_STREAM, ENGINE_OP_GET, ENGINE_OP_POST, ENGINE_OP_DELETE,
+from .invariant import (DECODE_PLAIN_TEXT, DECODE_HTML, DECODE_TAG_STREAM,
     MEDIA_TYPE_802_3, MEDIA_SUB_TYPE_NATIVE, OMNI_GET_STATS, OMNI_EXPERT_EXECUTE_QUERY,
     OMNI_GET_STATS_CONTEXT)
 
 # from expertresult import _create_expert_result_list
-from .mediainfo import MediaInfo
+from .invariant import EngineDataFormat as DF
+from .mediainformation import MediaInformation
 # from nodestatistic import NodeStatistic
 from .omnierror import OmniError
 from .omniid import OmniId
@@ -44,7 +44,7 @@ _forensic_prop_dict = {
     'linkSpeed': 'link_speed',
     'loadPercentProgress': 'load_progress',
     'loadProgress': 'load_percent',
-    'mediaInfo': 'media_info',
+    'mediaInfo': 'media_information',
     'mediaType': 'media_type',
     'mediaSubtype': 'media_sub_type',
     'modificationBy': 'modified_by',
@@ -122,8 +122,8 @@ class ForensicSearch(object):
     Or 'Load Completed' when completed.
     """
 
-    media_info = MediaInfo()
-    """The :class:`MediaInfo <omniscript.forensicsearch.MediaInfo>` about the
+    media_information = MediaInformation()
+    """The :class:`MediaInformation <omniscript.forensicsearch.MediaInformation>` about the
     search.
     """
 
@@ -221,7 +221,7 @@ class ForensicSearch(object):
         self.link_speed = ForensicSearch.link_speed
         self.load_progress = ForensicSearch.load_progress
         self.load_percent = ForensicSearch.load_percent
-        self.media_info = MediaInfo()
+        self.media_information = MediaInformation()
         self.media_type = ForensicSearch.media_type
         self.media_sub_type = ForensicSearch.media_sub_type
         self.modified_by = ForensicSearch.modified_by
@@ -342,7 +342,7 @@ class ForensicSearch(object):
         if number < self.first_packet:
             return None
         command = f'forensic-searches/{self.id.format()}/packets/{number}/'
-        resp = self._engine._issue_command(command, ENGINE_OP_GET)
+        resp = self._engine._issue_command(command)
         data = bytearray(resp['data'])
         return data
 
@@ -359,16 +359,16 @@ class ForensicSearch(object):
         if number < self.first_packet:
             return None
         if format == DECODE_PLAIN_TEXT:
-            decode = ENGINE_FORMAT_PLAIN
+            decode = DF.PLAIN
         elif format == DECODE_HTML:
-            decode = ENGINE_FORMAT_HTML
+            decode = DF.HTML
         elif format == DECODE_TAG_STREAM:
-            decode = ENGINE_FORMAT_TAG_STREAM
+            decode = DF.TAG_STREAM
         else:
             raise OmniError('Unrecognized format parameter.')
 
         command = f'forensic-searches/{self.id.format()}/packets/{number}/'
-        resp = self._engine._issue_command(command, ENGINE_OP_GET, decode)
+        resp = self._engine._issue_command(command, format=decode)
         return resp
 
     def get_protocol_stats(self):
@@ -434,8 +434,8 @@ class ForensicSearch(object):
                 setattr(self, a, int(v) != 0)
             elif isinstance(getattr(self, a), int):
                 setattr(self, a, int(v))
-            elif isinstance(getattr(self, a), MediaInfo):
-                self.media_info.load(v)
+            elif isinstance(getattr(self, a), MediaInformation):
+                self.media_information.load(v)
             elif isinstance(getattr(self, a), list):
                 if a == 'analysis_modules':
                     self.analysis_modules.append(OmniId(v))
@@ -496,7 +496,7 @@ class ForensicSearch(object):
             self.progress = search.progress
             self.start_time = search.start_time
             self.stop_time = search.stop_time
-            self.media_info = search.media_info
+            self.media_information = search.media_information
             self.option_expert = search.option_expert
             self.option_graphs = search.option_graphs
             self.option_indexing = search.option_indexing
