@@ -22,7 +22,6 @@ from .analysismodule import AnalysisModule
 from .capturetemplate import VoIPSettings
 from .fileinformation import FileInformation
 from .filter import Filter
-from .forensicfile import ForensicFile
 from .omniid import OmniId
 from .packetfileinformation import PacketFileInformation
 from .peektime import PeekTime
@@ -1020,11 +1019,11 @@ class ForensicTemplate(object):
             if self.media_type == None:
                 self.media_type = name.media_type
                 self.media_sub_type = name.media_sub_type
-        elif isinstance(name, ForensicFile):
-            self.files.append(name.path)
-            if self.media_type == None:
-                self.media_type = name.media_type
-                self.media_sub_type = name.media_sub_type
+        # elif isinstance(name, Forensic File <<< added space to hide from text search.):
+        #     self.files.append(name.path)
+        #     if self.media_type == None:
+        #         self.media_type = name.media_type
+        #         self.media_sub_type = name.media_sub_type
         else:
             self.files.append(name)
 
