@@ -165,21 +165,42 @@ def parse_ethernet(address):
         octets = list(([address[i:i+2] for i in range(0, 12, 2)]))
         mask = None
     else:
-        octets = address.upper().split(':')
-        for i in range(6):
-            if octets[i] == '*' or has_wild:
-                octets[i] = '0'
-                has_wild = True
-            else:
-                mask |= bit_mask
-            bit_mask = bit_mask >> 1
-            
-        addr = ''.join(o.zfill(2) for o in octets)
-        if mask == 0xFC000000:
+        if ':' in address:
+            octets = address.upper().split(':')
+            for i in range(6):
+                if octets[i] == '*' or has_wild:
+                    octets[i] = '0'
+                    has_wild = True
+                else:
+                    mask |= bit_mask
+                bit_mask = bit_mask >> 1
+            addr = ''.join(o.zfill(2) for o in octets)
+            if mask == 0xFC000000:
+                mask = None
+        else:
+            addr = address
             mask = None
     return (addr, mask)
 
 
+def parse_ethernet_list(addresses, mask):
+    """Parse a list of Ethernet Addresses.
+    
+    Args:
+        addresses (str): list of addresses seperated by '\\r\\n' or
+        '\\n'.
+
+    Returns:
+        List of EthernetAddress objects.
+    """
+    _addresses = addresses
+    if '\\r' in addresses:
+        _address = addresses.replace('\\r', '')
+    _addresses = _addresses.strip('\\n')
+    lst = [EthernetAddress(a, mask=mask) for a in _addresses.split('\\n') if a]
+    return lst
+
+
 def parse_ipv4(address):
     """Parse an IPv4 Address.
     
@@ -219,6 +240,24 @@ def parse_ipv4(address):
     return (addr, mask)
 
 
+def parse_ipv4_list(addresses, mask):
+    """Parse a list of IPv4 Addresses.
+    
+    Args:
+        addresses (str): list of addresses seperated by '\\r\\n' or
+        '\\n'.
+
+    Returns:
+        List of IPv4Address objects.
+    """
+    _addresses = addresses
+    if '\\r' in addresses:
+        _addresses = addresses.replace('\\r', '')
+    _addresses = _addresses.strip('\\n')
+    lst = [IPv4Address(a, mask=mask) for a in _addresses.split('\\n') if a]
+    return lst
+
+
 def parse_ipv6(address):
     """Parse an IPv6 Address.
     
@@ -247,6 +286,24 @@ def parse_ipv6(address):
     return data
 
 
+def parse_ipv6_list(addresses, mask):
+    """Parse a list of IPv6 Addresses.
+    
+    Args:
+        address (str): list of addresses seperated by '\\r\\n' or
+        '\\n'.
+
+    Returns:
+        List of IPv6Addres objects.
+    """
+    _addresses = addresses
+    if '\\r' in addresses:
+        _addresses = addresses.replace('\\r', '')
+    _addresses = _addresses.strip('\\n')
+    lst = [IPv6Address(a, mask=mask) for a in _addresses.split('\\n') if a]
+    return lst
+
+
 class BaseAddress(object):
     """The BaseAddress class is the base class for all Address
     classes.
@@ -308,7 +365,10 @@ class EthernetAddress(BaseAddress):
 ##                        addr + r'/' + str(_high_bits_set(cidr))
 ##                self.addresses.append(addr)
 
-    def __str__(self):
+    def __repr__(self) -> str:
+        return f'EthernetAddress: {format_ethernet(self.address)}'
+
+    def __str__(self) -> str:
         return format_ethernet(self.address)
 
     @property
@@ -347,7 +407,10 @@ class IPv4Address(BaseAddress):
 ##                        addr + r'/' + str(cidr)
 ##                self.addresses.append(addr)
 
-    def __str__(self):
+    def __repr__(self) -> str:
+        return f'IPv4Address: {format_ipv4(self.address, self.mask)}'
+
+    def __str__(self) -> str:
         return format_ipv4(self.address, self.mask)
 
     @property
@@ -394,6 +457,9 @@ class IPv6Address(BaseAddress):
 ##                        addr + r'/' + str(cidr)
 ##                self.addresses.append(addr)
 
+    def __repr__(self):
+        return f'IPv6: {format_ipv6(self.address, self.compressed)}'
+
     def __str__(self):
         return format_ipv6(self.address, self.compressed)
 
@@ -417,10 +483,16 @@ class OtherAddress(BaseAddress):
     Format is '1234', ASCII-Hex string.
     """
 
-    def __init__(self, mask, data):
+    def __init__(self, data, mask):
         BaseAddress.__init__(self, False, mask)
         self.address = data
 
+    def __repr__(self) -> str:
+        return f'OtherAddress: {self.address}'
+
+    def __str__(self) -> str:
+        return self.address
+
     @property
     def _data(self):
         return self.address
@@ -435,25 +507,13 @@ class OmniAddress(object):
 
     name = None
 
-    address = None
-    """One of the BaseAddress class of address."""
+    address_list = None
+    """A list of one of the BaseAddress class of address."""
 
     def __init__(self, name, address, address_type=None, mask=None):
-        if isinstance(address, BaseAddress):
-            self.name = name
-            self.address = address
-        if isinstance(address, six.string_types):
-            series = False
-            if address_type == ADDRESS_TYPE_ETHERNET:
-                self.address = EthernetAddress(address, series, mask)
-            elif address_type == ADDRESS_TYPE_IP:
-                self.address = IPv4Address(address, series, mask)
-            elif address_type == ADDRESS_TYPE_IPV6:
-                self.address = IPv6Address(address, series, mask)
-            elif address_type == ADDRESS_TYPE_WIRELESS:
-                self.address = EthernetAddress(address, series, mask)
-            else:
-                self.address = OtherAddress(mask, address)
+        self.name = name
+        self.address_list = OmniAddress.address_list
+        self._load(address, address_type, mask)
         # elif isinstance(address, ET.Element):
         #     self._load(address)
 
@@ -482,7 +542,23 @@ class OmniAddress(object):
         """The type of the address. (Read Only)"""
         return self.address.address_type
 
-    def _load(self, node):
+    def _load(self, address, address_type=None, mask=None):
+        if isinstance(address, BaseAddress):
+            self.address_list = [address]
+        if isinstance(address, six.string_types):
+            series = False
+            if address_type == ADDRESS_TYPE_ETHERNET:
+                self.address_list = parse_ethernet_list(address, mask)
+            elif address_type == ADDRESS_TYPE_IP:
+                self.address_list = parse_ipv4_list(address, mask)
+            elif address_type == ADDRESS_TYPE_IPV6:
+                self.address_list = parse_ipv6_list(address, mask)
+            elif address_type == ADDRESS_TYPE_WIRELESS:
+                self.address_list = parse_ethernet_list(address, mask)
+            else:
+                self.address_list = [OtherAddress(address, mask)]
+
+    def _load_xml(self, node):
         self.name = node.tag
         series = (self.name[0].lower() == 's')
         address_type = int(node.get('type', '0'))
@@ -491,17 +567,17 @@ class OmniAddress(object):
             mask = int(mask)
         data = node.get('data')
         if address_type == ADDRESS_TYPE_ETHERNET:
-            self.address = EthernetAddress(None, series, mask, data)
+            self.address_list = EthernetAddress(None, series, mask, data)
         elif address_type == ADDRESS_TYPE_IP:
-            self.address = IPv4Address(None, series, mask, data)
+            self.address_list = IPv4Address(None, series, mask, data)
         elif address_type == ADDRESS_TYPE_IPV6:
-            self.address = IPv6Address(None, series, mask, data)
+            self.address_list = IPv6Address(None, series, mask, data)
         elif address_type == ADDRESS_TYPE_WIRELESS:
-            self.address = EthernetAddress(None, series, mask, data)
+            self.address_list = EthernetAddress(None, series, mask, data)
         else:
-            self.address = OtherAddress(mask, data)
+            self.address_list = OtherAddress(data, mask)
 
-    def _store(self, node):
+    def _store_xml(self, node):
         elem = ET.SubElement(node, self.name,
                              {'class':'2',
                               'type':str(self.address.address_type),
@@ -509,17 +585,17 @@ class OmniAddress(object):
         if self.mask is not None:
             elem.set('mask', str(self.mask))
 
-    def parse(self, address):
-        if address.find('.'):
-            offset = address.find('/')
-            series = offset != -1
-            if series:
-                mask = int(address[offset+1:])
-                data = address[:offset]
-            else:
-                mask = 0
-                data = address
-            self.address = IPv4Address(series, mask, data)
+    # def parse(self, address):
+    #     if address.find('.'):
+    #         offset = address.find('/')
+    #         series = offset != -1
+    #         if series:
+    #             mask = int(address[offset+1:])
+    #             data = address[:offset]
+    #         else:
+    #             mask = 0
+    #             data = address
+    #         self.address = IPv4Address(series, mask, data)
             
 
 def parse_ip_address(address):
